cloudhypervisor

package
v0.0.0-...-364cddf Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 4, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Default = NewCloudHypervisor("cloud-hypervisor")

Functions

This section is empty.

Types

type CloudHypervisor

type CloudHypervisor struct {
	// contains filtered or unexported fields
}

func NewCloudHypervisor

func NewCloudHypervisor(command string) *CloudHypervisor

func (*CloudHypervisor) Start

func (c *CloudHypervisor) Start(ctx context.Context, apiSocket string) (client.Client, error)

Directories

Path Synopsis
Package oapiclient provides primitives to interact with the openapi HTTP API.
Package oapiclient provides primitives to interact with the openapi HTTP API.

Jump to